"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var equals = tslib_1.__importStar(require("shallowequal"));
/**
 * Context.
 */
var Context = /** @class */ (function () {
    function Context() {
        /**
         * Consumer's select props as bitmask.
         */
        this.bitmask = new Map();
    }
    /**
     * calculate bitmask.
     */
    Context.prototype.calculateBitmask = function (nextState) {
        return Array.from(this.bitmask.entries()).reduce(function (bits, _a) {
            var select = _a[0], bitState = _a[1];
            var next = select(nextState);
            var isSame = equals.default(next, bitState.state);
            if (!isSame) {
                bitState.state = next;
                bitState.version++;
                return bits | bitState.bit;
            }
            return bits;
        }, 0);
    };
    /**
     * register select function.
     */
    Context.prototype.register = function (select) {
        this.bitmask.set(select, {
            bit: this.bitmask.size + 1,
            version: 1
        });
    };
    /**
     * getBitState.
     */
    Context.prototype.getBitState = function (select) {
        return this.bitmask.get(select);
    };
    return Context;
}());
exports.Context = Context;
//# sourceMappingURL=Context.js.map