import * as equals from "shallowequal";
/**
 * Context.
 */
export class Context {
    constructor() {
        /**
         * Consumer's select props as bitmask.
         */
        this.bitmask = new Map();
    }
    /**
     * calculate bitmask.
     */
    calculateBitmask(nextState) {
        return Array.from(this.bitmask.entries()).reduce((bits, [select, bitState]) => {
            const next = select(nextState);
            const isSame = equals.default(next, bitState.state);
            if (!isSame) {
                bitState.state = next;
                bitState.version++;
                return bits | bitState.bit;
            }
            return bits;
        }, 0);
    }
    /**
     * register select function.
     */
    register(select) {
        this.bitmask.set(select, {
            bit: this.bitmask.size + 1,
            version: 1
        });
    }
    /**
     * getBitState.
     */
    getBitState(select) {
        return this.bitmask.get(select);
    }
}
//# sourceMappingURL=Context.js.map